use std::net::SocketAddr;
use axum::Router;
use axum::routing::get;
use askama::Template;
use axum::http::StatusCode;
use axum::response::{Html, IntoResponse};

use super::common::STATE;

pub async fn main() {
    let app = Router::new()
        .route("/", get(root));

    let addr = SocketAddr::from(([127, 0, 0, 1], 3000));
    axum::Server::bind(&addr)
        .serve(app.into_make_service())
        .await
        .unwrap();
}

async fn root() -> impl IntoResponse {
    let name = STATE.lock().unwrap().clone().name();
    let tmpl = RootTemplate { name };
    match tmpl.render() {
        Ok(html) => Html(html).into_response(),
        Err(err) => (
            StatusCode::INTERNAL_SERVER_ERROR,
            Html(format!("Template error:<br><pre>{}</pre>", err))
        ).into_response(),
    }
}

#[derive(Template)]
#[template(path = "index.html")]
struct RootTemplate {
    name: String
}
